courses.Enrolment (Enrolment) — amici1

# `courses.Enrolment` (Enrolment)

Enrolment(id, start_date, end_date, user, printed_by, course_area, course, pupil, request_date, state, places, remark, confirmation_details)

Master tables : courses.AllEnrolments (Enrolments), courses.Enrolments (Enrolments), courses.PendingConfirmedEnrolments (Pending confirmed enrolments), courses.PendingRequestedEnrolments (Pending requested enrolments)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Start date (start_date) : See `<django.db.models.fields.DateField: start_date>`.

- End date (end_date) : See `<django.db.models.fields.DateField: end_date>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Printed (printed_by) : ForeignKey to the Excerpt which certifies this instance.

- Layout (course_area) : See `<lino.core.choicelists.ChoiceListField: course_area>`.

- Activity (course) : See `<django.db.models.fields.related.ForeignKey: course>`.

- Participant (pupil) : See `<django.db.models.fields.related.ForeignKey: pupil>`.

- Date of request (request_date) : See `<django.db.models.fields.DateField: request_date>`.

- State (state) : One of lino_xl.lib.courses.EnrolmentStates.

- Places used (places) : The number of participants in this enrolment.

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

- Confirmation details (confirmation_details) : See `<lino.core.fields.RichTextField: confirmation_details>`.

- Participant (pupil_info) : Virtual HtmlBox field showing the name and address of the participant.

- Name (name_column) : See `lino_xl.lib.courses.models.Enrolment.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.courses.models.Enrolment.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- Activity (overview) : See `lino_xl.lib.courses.models.Enrolment.overview`.

- Printed (printed) : Displays information about when this certifiable has been printed. Clicking on it will display the excerpt pointed to by printed_by.

- Activity (overview) : See `lino_xl.lib.courses.models.Enrolment.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
start_date | Start date |
end_date | End date |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
printed_by | Printed | ForeignKey to the Excerpt which certifies this instance.
course_area | Layout |
course | Activity |
pupil | Participant |
request_date | Date of request |
state | State | One of lino_xl.lib.courses.EnrolmentStates.
places | Places used | The number of participants in this enrolment.
remark | Remark |
confirmation_details | Confirmation details |
pupil_info | Participant | Virtual HtmlBox field showing the name and address of the participant.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | Activity |
printed | Printed | Displays information about when this certifiable has been printed. Clicking on it will display the excerpt pointed to by printed_by.
overview | Activity |